Changes
=======

Version 0.1
-------------

* Basic social network activity fetching with cache. 

Version 0.1.1
-------------

* Updated readme with some examples. 

Version 0.1.2
-------------

* Fix readme code errors. 
